DEFAULT_SEARCH_ATTRIBUTES = [
    "name",
    "display_name",
    "description",
    "qualified_name",
    "user_description",
    "certificate_status",
    "owner_users",
    "connector_name",
    "has_lineage",
    "source_created_at",
    "source_updated_at",
    "readme",
    "owner_groups",
    "asset_tags",
]
